@@ -3,6 +3,7 @@ import subprocess
 
 from devinstaller_core import exception as e
 from devinstaller_core import extension as ex
+from devinstaller_core import settings as s
 
 
 class ExtSpec(ex.ExtSpec):
@@ -19,6 +20,9 @@ class ExtSpec(ex.ExtSpec):
             CommandFailed
         """
         try:
-            subprocess.run(shlex.split(command))
+            capture_output = not s.settings.DDOT_VERBOSE
+            subprocess.run(shlex.split(command), capture_output=capture_output)
         except subprocess.CalledProcessError as err:
             raise e.CommandFailed(returncode=err.returncode, cmd=err.cmd)
+        except Exception:
+            raise e.CommandFailed(returncode=1, cmd=command)
